# auto_sender

适用于可公开的数据，比如摘抄本，个人博客，笔记等。

比如，我在个人电脑的某个专用文件夹，放了许多个人博客文章，每篇文章是一个以 .md 结尾的文本文件。

auto_sender 的作用是：

1、把该文件夹与 rum group 形成映射；

2、把文件夹下的每个文本文件，映射一条 trx；

3、然后自动或手动提交/更新/同步。

为什么？

存储在 rum group 的数据，既是可靠的、分布式的数据备份，可一键恢复到新的指定目录或新设备上；也可以作为产品的数据源，比如论坛的主帖，博客主的个人文集，被运用到 port.base.one 等相似的站点。

关于：

采用 python 实现，偏后端，作为 demo 而存在，目前几乎没有图形交互。

换言之，rum group 的数据可以采用任何已有的产品应用来渲染，这个 bot 只处理原始数据与 rum group 的映射与同步。

### 安装

```sh
pip install rum_auto_sender
```

### 使用

[example](./example/bot_blog.py)